@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 from collections import deque, defaultdict
 from datetime import timedelta
 import functools
@@ -16,10 +14,6 @@ from tornado import gen
 from tornado.locks import Condition
 from tornado.ioloop import IOLoop
 from tornado.queues import Queue
-try:
-    from tornado.ioloop import PollIOLoop
-except ImportError:
-    PollIOLoop = None  # dropped in tornado 6.0
 
 try:
     from distributed.client import default_client as _dask_default_client
@@ -385,14 +379,16 @@ class Stream(APIRegisterMixin):
 
     def _ipython_display_(self, **kwargs):  # pragma: no cover
         try:
-            from ipywidgets import Output
+            import ipywidgets
             from IPython.core.interactiveshell import InteractiveShell
+            output = ipywidgets.Output(_view_count=0)
         except ImportError:
+            # since this function is only called by jupyter, this import must succeed
+            from IPython.display import display, HTML
             if hasattr(self, '_repr_html_'):
-                return self._repr_html_()
+                return display(HTML(self._repr_html_()))
             else:
-                return self.__repr__()
-        output = Output(_view_count=0)
+                return display(self.__repr__())
         output_ref = weakref.ref(output)
 
         def update_cell(val):
@@ -1995,11 +1991,6 @@ def sync(loop, func, *args, **kwargs):
     """
     # This was taken from distrbuted/utils.py
 
-    # Tornado's PollIOLoop doesn't raise when using closed, do it ourselves
-    if PollIOLoop and ((isinstance(loop, PollIOLoop) and getattr(loop, '_closing', False))
-            or (hasattr(loop, 'asyncio_loop') and loop.asyncio_loop._closed)):
-        raise RuntimeError("IOLoop is closed")
-
     timeout = kwargs.pop('callback_timeout', None)
 
     e = threading.Event()
